#
# spec file for package plasma6-systemmonitor
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.0.0
%define qt6_version 6.6.0

%define rname plasma-systemmonitor

%bcond_without released
# Full Plasma 6 version (e.g. 6.0.0)
%{!?_plasma6_bugfix: %define _plasma6_bugfix %{version}}
# Latest ABI-stable Plasma (e.g. 6.0 in KF6, but 6.0.80 in KUF)
%{!?_plasma6_version: %define _plasma6_version %(echo %{_plasma6_bugfix} | awk -F. '{print $1"."$2}')}
Name:           plasma6-systemmonitor
Version:        6.0.3
Release:        1.1
Summary:        An application for monitoring system resources
License:        GPL-3.0-only
URL:            https://www.kde.org
Source0:        https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6GlobalAccel) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6ItemModels) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6KirigamiAddons)
BuildRequires:  cmake(KF6NewStuff) >= %{kf6_version}
BuildRequires:  cmake(KF6Package) >= %{kf6_version}
BuildRequires:  cmake(KF6Service) >= %{kf6_version}
BuildRequires:  cmake(KSysGuard) >= %{_plasma6_bugfix}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
Requires:       kf6-kiconthemes-imports >= %{kf6_version}
Requires:       kf6-kirigami-imports >= %{kf6_version}
Requires:       kf6-kitemmodels-imports >= %{kf6_version}
Requires:       kf6-knewstuff-imports >= %{kf6_version}
Requires:       kf6-kquickcharts >= %{kf6_version}
Requires:       kf6-qqc2-desktop-style >= %{kf6_version}
Requires:       kirigami-addons6
Requires:       ksystemstats6 >= %{_plasma6_bugfix}
Requires:       qt6-declarative-imports >= %{qt6_version}
Provides:       plasma5-systemmonitor = %{version}
Obsoletes:      plasma5-systemmonitor < %{version}
Obsoletes:      plasma5-systemmonitor-lang < %{version}

%description
plasma-systemmonitor provides an interface for monitoring system sensors,
process information and other system resources.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%suse_update_desktop_file org.kde.plasma-systemmonitor System Monitor

%fdupes %{buildroot}%{_kf6_sharedir}

%find_lang %{name} --all-name

%ldconfig_scriptlets

%files
%license LICENSES/*
%doc README.md
%{_kf6_applicationsdir}/org.kde.plasma-systemmonitor.desktop
%{_kf6_appstreamdir}/org.kde.plasma-systemmonitor.metainfo.xml
%{_kf6_bindir}/plasma-systemmonitor
%{_kf6_configkcfgdir}/systemmonitor.kcfg
%{_kf6_knsrcfilesdir}/plasma-systemmonitor.knsrc
# FIXME result of 105cb99d & bb8d4048
%{_kf6_libdir}/libPlasmaSystemMonitorPage.so
%{_kf6_libdir}/libPlasmaSystemMonitorTable.so
%dir %{_kf6_qmldir}/org/kde/ksysguard/
%{_kf6_qmldir}/org/kde/ksysguard/page/
%{_kf6_qmldir}/org/kde/ksysguard/table/
%dir %{_kf6_sharedir}/ksysguard/
%{_kf6_sharedir}/ksysguard/sensorfaces/
%{_kf6_sharedir}/plasma-systemmonitor/
%dir %{_kf6_sharedir}/plasma/kinfocenter/
%dir %{_kf6_sharedir}/plasma/kinfocenter/externalmodules/
%{_kf6_sharedir}/plasma/kinfocenter/externalmodules/kcm_external_plasma-systemmonitor.desktop
%dir %{_kf6_sharedir}/kglobalaccel/
%{_kf6_sharedir}/kglobalaccel/org.kde.plasma-systemmonitor.desktop

%files lang -f %{name}.lang

%changelog
* Tue Mar 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.3
- Changes since 6.0.2:
  * revert duplicate appstream update
  * update version for new release
  * GlobalMenu: Fix path to AboutPage.qml
  * page: Fix drag-sorting of pages in PageSortDialog (kde#482377)
* Wed Mar 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.2
- Changes since 6.0.1:
  * update version for new release
* Wed Mar  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.1
- Changes since 6.0.0:
  * update version for new release
* Mon Mar  4 2024 Christophe Marin <christophe@krop.fr>
- Add Provides/Obsoletes to replace Plasma 5
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0:
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.93.0:
  * update version for new release
  * table: Explicitly disable dragging beyond bounds in header (kde#481224)
  * page: Fix missing sensors display when not editing
  * Add a workaround for QTBUG-114999
  * table: Use upstream table selection behavior (kde#479329)
  * Only store window geometry if the window is in "Windowed" state (kde#478442)
  * page: Fix warning about signal parameter injection in FaceConfigurationPage
  * Slightly increase the width of the face configuration page
  * page: Properly constrain the size of config/sensors items in FaceConfigPage (kde#480986)
  * table: Ensure we update sortName when changing sort order (kde#480950)
  * Enable hover tooltips for entries in ColumnConfigurationDialog
  * Make face cache entries unique per-page (kde#480160)
  * table: Fix sorting of tables using the header (kde#479326)
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.93.0 (6.0 RC 2):
  * New bugfix release
  * See https://kde.org/announcements/megarelease/6/rc2/ for details
- Changes since 5.92.0:
  * Migrate existing system activity shortcut
  * Clip scrollable listviews (kde#479324)
* Wed Jan 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.92.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Fri Jul 14 2023 Christophe Marin <christophe@krop.fr>
- Init plasma6-systemmonitor
